ch_ews is used to estimate changes in conditional
heteroskedasticity within rolling windows along a
timeseriesch_ews(timeseries, winsize = 10, alpha = 0.1,
optim = TRUE, lags = 4, logtransform = FALSE,
interpolate = FALSE)lags is selected.ch_ews returns a matrix that contains:alpha level for 1 degree of freedom
divided by the number of residuals used in the
regression.optim
FALSE was selected.ch_ews plots the original timeseries
and the R2 where the level of significance is also
indicated.Dakos, V., et al (2012)."Methods for Detecting Early Warnings of Critical Transitions in Time Series Illustrated Using Simulated Ecological Data." PLoS ONE 7(7): e41010. doi:10.1371/journal.pone.0041010
generic_ews; ddjnonparam_ews;
bdstest_ews; sensitivity_ews;
surrogates_ews; ch_ews;
movpotential_ews; livpotential_ewsdata(foldbif)
out=ch_ews(foldbif, winsize=50, alpha=0.05, optim=TRUE, lags)Run the code above in your browser using DataLab