ddjnonparam_ews is used to compute
nonparametrically conditional variance, drift, diffusion
and jump intensity in a timeseries. It also interpolates
to obtain the evolution of the nonparametric statistics
in time.ddjnonparam_ews(timeseries, bandwidth = 0.6, na = 500,
logtransform = TRUE, interpolate = FALSE)ddjnonparam_ews returns an object with elements:x over avec.dx
over avec.total variance - jumping intensity vs
avec.avec.x data over Tvec1.dx over
Tvec1.Tvec1.Tvec1.ddjnonparam_ews returns a first plot
with the original timeseries and the residuals after
first-differencing. A second plot shows the nonparametric
conditional variance, total variance, diffusion and jump
intensity over the data, and a third plot the same
nonparametric statistics over time.Dakos, V., et al (2012)."Methods for Detecting Early Warnings of Critical Transitions in Time Series Illustrated Using Simulated Ecological Data." PLoS ONE 7(7): e41010. doi:10.1371/journal.pone.0041010
generic_ews; ddjnonparam_ews;
bdstest_ews;
sensitivity_ews;surrogates_ews;
ch_ews; movpotential_ews;
livpotential_ewsdata(foldbif)
output<-ddjnonparam_ews(foldbif,bandwidth=0.6,na=500,
logtransform=TRUE,interpolate=FALSE)Run the code above in your browser using DataLab