Learn R Programming

earlywarnings (version 1.0.32)

livpotential_ews: Description: Potential Analysis

Description

livpotential_ews performs one-dimensional potential estimation derived from a uni-variate timeseries

Usage

livpotential_ews(x, std = 1, bw = -1, xi = NULL,
    weights = c(), grid.size = 200)

Arguments

x
data vector
std
the standard deviation of the noise (defaults to 1, so then you use scaled potentials
bw
bandwidth for kernel estimation
xi
x values at which the potential is estimated
weights
optional weights in ksdensity (used by movpotentials).
grid.size
grid size

Value

  • livpotential returns a list with the following elements:
  • xithe grid of points on which the potential is estimated
  • potthe actual value of the potential
  • minimathe grid points at which the potential has minimum values
  • maximathe grid points at which the potential has maximum values
  • bwbandwidth of kernel used

Details

see ref below

References

Livina, VN, F Kwasniok, and TM Lenton, 2010. Potential analysis reveals changing number of climate states during the last 60 kyr . Climate of the Past, 6, 77-82.

Dakos, V., et al (2012)."Methods for Detecting Early Warnings of Critical Transitions in Time Series Illustrated Using Simulated Ecological Data." PLoS ONE 7(7): e41010. doi:10.1371/journal.pone.0041010

See Also

generic_ews; ddjnonparam_ews; bdstest_ews; sensitivity_ews;surrogates_ews; ch_ews;movpotential_ews

Examples

Run this code
data(foldbif)
res <- livpotential_ews(foldbif)
plot(res$xi, res$pot)

Run the code above in your browser using DataLab