Learn R Programming

earlywarnings (version 1.0.32)

movpotential_ews: Description: Moving Average Potential

Description

movpotential_ews reconstructs a potential derived from data along a gradient of a given parameter the movpotential_ews calculates the potential for values that correspond to a particular parameter. see ref below

Usage

movpotential_ews(X, param, sdwindow = NULL, bw = -1,
    minparam = NULL, maxparam = NULL, npoints = 50,
    thres = 0.002, std = 1, grid.size = 200, cutoff = 0.5)

Arguments

X
a vector of the X observations of the state variable of interest
param
parameter values that correspond to the X observations
sdwindow
window for smoothing kernels (over the param axis)
bw
bandwidth used for smoothing kernels
minparam
minimum value of parameter on which to estimate potential
maxparam
maximum value of parameter on which to estimate potential
npoints
number of potentials
thres
threshold for local minima to be discarded
std
std
grid.size
number of evaluation points
cutoff
the cuttof value to estimate minima and maxima in the potential

Returns:

Value

  • A list with the following elements:
  • parsvalues of the covariate parameter as matrix
  • xisvalues of the x as matrix
  • potssmoothed potentials
  • minsminima in the densities (-potentials; neglecting local optima)
  • maxsmaxima in densities (-potentials; neglecting local optima)
  • plotan object that displays the potential estimated in 2D

References

Hirota, M., Holmgren, M., van Nes, E.H. & Scheffer, M. (2011). Global resilience of tropical forest and savanna to critical transitions. Science, 334, 232-235.

See Also

generic_ews; ddjnonparam_ews; bdstest_ews; sensitivity_ews;surrogates_ews; ch_ews; livpotential_ews

Examples

Run this code
X = c(rnorm(1000, mean = 0), rnorm(1000, mean = -2), rnorm(1000, mean = 2))
 param = seq(0,5,length=3000)
 res <- movpotential_ews(X, param, npoints = 100, thres = 0.003)

Run the code above in your browser using DataLab