sensitivity_ews is used to estimate trends in
statistical moments for different sizes of rolling
windows along a timeseries. The trends are estimated by
the nonparametric Kendall tau correlation coefficient.sensitivity_ews(timeseries,
indicator = c("ar1", "sd", "acf1", "sk", "kurt", "cv", "returnrate", "densratio"),
winsizerange = c(25, 75), incrwinsize = 25,
detrending = c("no", "gaussian", "linear", "first-diff"),
bandwidthrange = c(5, 100), incrbandwidth = 20,
logtransform = FALSE, interpolate = FALSE)ar1
autoregressive coefficient of a first order AR model,
sd standard deviation, gaussian filtering, linear detrending and
first-differencing. Default is no
detrending.sensitivity_ews returns a matrix that contains the
Kendall tau rank correlation estimates for the rolling
window sizes (rows) and bandwidths (columns), if
gaussian filtering is selected. In addition, sensitivity_ews returns a plot with
the Kendall tau estimates and their p-values for the
range of rolling window sizes used, together with a
histogram of the distributions of the statistic and its
significance. When gaussian filtering is chosen, a
contour plot is produced for the Kendall tau estimates
and their p-values for the range of both rolling window
sizes and bandwidth used. A reverse triangle indicates
the combination of the two parameters for which the
Kendall tau was the highest
Dakos, V., et al (2012)."Methods for Detecting Early Warnings of Critical Transitions in Time Series Illustrated Using Simulated Ecological Data." PLoS ONE 7(7): e41010. doi:10.1371/journal.pone.0041010
generic_ews; ddjnonparam_ews;
bdstest_ews; sensitivity_ews;
surrogates_ews; ch_ews;
movpotential_ews;
livpotential_ewsdata(foldbif)
output=sensitivity_ews(foldbif,indicator="sd",detrending="gaussian",
incrwinsize=25,incrbandwidth=20)Run the code above in your browser using DataLab