surrogates_ews is used to estimate distributions
of trends in statistical moments from different surrogate
timeseries generated after fitting an ARMA(p,q) model on
the data. The trends are estimated by the nonparametric
Kendall tau correlation coefficient and can be compared
to the trends estimated in the original timeseries to
produce probabilities of false positives.surrogates_ews(timeseries,
indicator = c("ar1", "sd", "acf1", "sk", "kurt", "cv", "returnrate", "densratio"),
winsize = 50,
detrending = c("no", "gaussian", "linear", "first-diff"),
bandwidth = NULL, boots = 100, logtransform = FALSE,
interpolate = FALSE)ar1
autoregressive coefficient of a first order AR model,
sd standard deviation, gaussian filtering, linear
detrending and first-differencing. Default is
no detrending.surrogates_ews returns a matrix that contains:surrogates_ews returns a plot with
the distribution of the surrogate Kendall tau estimates
and the Kendall tau estimate of the original series.
Vertical lines indicate the 5% and 95% significance
levels.Dakos, V., et al (2012)."Methods for Detecting Early Warnings of Critical Transitions in Time Series Illustrated Using Simulated Ecological Data." PLoS ONE 7(7): e41010. doi:10.1371/journal.pone.0041010
generic_ews; ddjnonparam_ews;
bdstest_ews; sensitivity_ews;
surrogates_ews; ch_ews;
movpotential_ews;
livpotential_ewsdata(foldbif)
output=surrogates_ews(foldbif,indicator="sd",winsize=50,detrending="gaussian",
bandwidth=10,boots=200,logtransform=FALSE,interpolate=FALSE)Run the code above in your browser using DataLab